#
# spec file for package talk
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global         ncursesw_config %(set -- %{_bindir}/ncursesw*-config; echo ${1})
Name:           talk
Version:        0.17
Release:        bp160.1.7
Summary:        Talk Client for Chatting with Another User
License:        BSD-3-Clause
Group:          Productivity/Networking/Talk/Clients
URL:            ftp://ftp.uk.linux.org/pub/linux/Networking/netkit/
Source:         netkit-ntalk-%{version}.tar.bz2
Source4:        ntalk.service
Source5:        ntalk.socket
Patch0:         netkit-ntalk-%{version}.dif
Patch1:         netkit-ntalk-multibyte.diff
Patch2:         netkit-ntalk-%{version}-alt-talkd.patch
Patch3:         netkit-ntalk-%{version}-strip.diff
Patch4:         netkit-ntalk-%{version}-dont-resolve.patch
Patch5:         netkit-n%{name}-0.17-dots_in_usernames.patch
# PATCH-FIX-UPSTREAM netkit-ntalk-0.17-close_file_on_failure.patch
Patch6:         netkit-ntalk-0.17-close_file_on_failure.patch
Patch7:         netkit-ntalk-curses-lvalue.patch
# build with gcc14
Patch8:         talk-gcc14.patch
BuildRequires:  ncurses-devel
Provides:       nkitb:%{_bindir}/talk
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  systemd-rpm-macros

%description
This package contains the talk client, which allows you to chat with
another user on a different system. Talk is a communication program
which copies lines from one terminal to that of another user.

%package server
Version:        0.17
Release:        bp160.1.7
Summary:        Talk Daemon to Chat with Another User
Group:          Productivity/Networking/Talk/Servers
Requires:       net-tools
Requires:       netcfg libnss_usrfiles2
Provides:       nkitserv:%{_sbindir}/in.talkd
%{?systemd_requires}

%description server
This package contains the talk daemon, which allows you to chat with
another user on a different system. Talk is a communication program
which copies lines from one terminal to the terminal of another user.

%prep
%autosetup -p1 -n netkit-ntalk-%{version}

%build
# Not autotools configure macro
CFLAGS="%{optflags}" ./configure
cat <<-EOF >> MCONFIG
	LIBCURSES=$(%{ncursesw_config} --libs)
	CFLAGS += -D_GNU_SOURCE -fPIE  $(%{ncursesw_config} --cflags)
	LDFLAGS += -pie
EOF
make %{?_smp_mflags}

%install
install -d -m 755 %{buildroot}%{_prefix}/{bin,sbin}
install -d -m 755 %{buildroot}%{_mandir}/man{1,8}
make install INSTALLROOT=%{buildroot}
install -D -m 644 %{SOURCE4} %{buildroot}/%{_unitdir}/ntalk.service
install -D -m 644 %{SOURCE5} %{buildroot}/%{_unitdir}/ntalk.socket

%files
%defattr(-,root,root)
%doc BUGS ChangeLog
%{_bindir}/talk
%{_mandir}/man1/*

%pre server
%service_add_pre ntalk.socket

%post server
%service_add_post ntalk.socket

%preun server
%service_del_preun ntalk.socket

%postun server
%service_del_postun ntalk.socket

%files server
%defattr(-,root,root)
%doc BUGS ChangeLog
%{_mandir}/man8/*
%{_sbindir}/in.ntalkd
%{_sbindir}/in.talkd
%{_unitdir}/ntalk.socket
%{_unitdir}/ntalk.service

%changelog
* Thu May  9 2024 pgajdos@suse.com
- fix build with gcc 14
- use %%autosetup
- modified patches
  %% netkit-ntalk-0.17-close_file_on_failure.patch (p1)
  %% netkit-ntalk-0.17-dont-resolve.patch (p1)
  %% netkit-ntalk-0.17-dots_in_usernames.patch (p1)
  %% netkit-ntalk-0.17-strip.diff (p1)
  %% netkit-ntalk-0.17.dif (p1)
  %% netkit-ntalk-multibyte.diff (p1)
- added patches
  fix build with gcc14
  + talk-gcc14.patch
* Mon Feb 26 2024 pgajdos@suse.com
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Jul 26 2019 matthias.gerstner@suse.com
- removal of SuSEfirewall2 service, since SuSEfirewall2 has been replaced by
  firewalld, see [1].
  [1]: https://lists.opensuse.org/opensuse-factory/2019-01/msg00490.html
* Thu Jun 15 2017 aliouliaki@suse.com
- Removed xinetd service
- Added ntalk.service and ntalk.socket
* Fri Feb 17 2017 pgajdos@suse.com
- fix build
  + netkit-ntalk-curses-lvalue.patch
* Sun Mar 15 2015 jengelh@inai.de
- Remove obsolete specfile tags and cleaning
* Fri Oct 16 2009 rschweikert@novell.com
- fixed file descriptor leak on failure (bnc#544908)
  netkit-ntalk-0.17-close_file_on_failure.patch
* Wed Aug  6 2008 anosek@suse.cz
- fixed Talk can't handle dots in user names (bnc#338368)
  (dots_in_usernames.patch)
* Thu Apr 10 2008 werner@suse.de
- Use correct header for libncursesw
* Thu Mar 29 2007 dmueller@suse.de
- add ncurses-devel BuildRequires
* Thu Mar  8 2007 anosek@suse.cz
- added port definitions for SuSEfirewall2 [#247352] (talkd.fw)
* Wed Jan 10 2007 anosek@suse.cz
- fixed: talkd does not allow connection from hosts without DNS
  record [#227396] (dont-resolve.patch)
* Tue Sep 19 2006 anosek@suse.cz
- talk server runs as nobody.tty (originally was root.root)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sun Jan 15 2006 schwab@suse.de
- Don't strip binaries.
* Mon Jun 20 2005 ro@suse.de
- build with fPIE/pie
* Mon Sep 20 2004 postadal@suse.cz
- fixed DoS [#44756] (alt-talkd.patch)
* Thu Feb 26 2004 hmacht@suse.de
- building as non-root
* Tue Mar  4 2003 kraxel@suse.de
- yet another multibyte patch fix (line erase not working correctly).
* Mon Feb 24 2003 vbobek@suse.cz
- created config file for xinetd
* Tue Jan 14 2003 kraxel@suse.de
- more multibyte patch fixes.
* Tue Dec 17 2002 kraxel@suse.de
- various minor fixes in the multibyte patch.
* Wed Dec 11 2002 kraxel@suse.de
- added locale and multibyte support.
* Thu Mar 22 2001 ro@suse.de
- added split-aliases as provides
* Fri Mar 16 2001 cihlar@suse.cz
- added Url
- claen up spec file
* Fri Mar  2 2001 kukuk@suse.de
- Initial package, split from nkitb
